# KMUHelper (English)

([Hier](./README.md) klicken für die deutsche Version.)

[![PyPI](https://img.shields.io/pypi/v/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - License](https://img.shields.io/pypi/l/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/blob/main/LICENSE)

[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub lines of code](https://img.shields.io/tokei/lines/github.com/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub issues](https://img.shields.io/github/issues/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/pulls)

[![CodeFactor](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper/badge)](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper)

The "KMUHelper" is a helper for small and medium-sizes swiss companies. (KMU = Kleine und Mittlere Unternehmen = Small and Medium-sized Enterprises = SME)

Its main feature is the creation of the new swiss QR invoice, which is a new standard for invoices in Switzerland.

The original version of this app is in German.
A translated version is in progress.

Information about the KMUHelper can be found on the [info page](https://rafaelurben.github.io/kmuhelper/) and in the [documentation](https://rafaelurben.github.io/django-kmuhelper/) (both currently only available in German).

## Changes and Feedback

The newest changes can be found in the [changelog](https://github.com/rafaelurben/django-kmuhelper/releases).

- [Discussions](https://github.com/rafaelurben/django-kmuhelper/discussions) - Questions and ideas
- [Issues](https://github.com/rafaelurben/django-kmuhelper/issues) - Bugs and Feature requests
- [Contact](mailto:kmuhelper@rafaelurben.ch) - Urgent issues/reports or general questions

Planned changes and current progress can be found in the [project board](https://github.com/users/rafaelurben/projects/5/views/2).

## Installation

See [here](https://rafaelurben.github.io/django-kmuhelper/installation). (German)

## Countries

The KMUHelper is currently only available for Switzerland (CH) and Liechtenstein (LI), although the latter hasn't been tested. There is no plan to add other countries because the swiss QR invoice is only valid in Switzerland and Liechtenstein.
